# your_package_name

## Description

This is a collection of handy functions for performing functional pipeline processing (Point-Free Style) in Python.

## Dependencies

This package depends on `toolz`, which is released under the New BSD License.

## License

This package is released under CC0. For details, please refer to the LICENSE file.
For license information regarding `toolz`, please see the following: [toolz GitHub Repository](https://github.com/pytoolz/toolz).
